=begin
/****************************************************************************
** $Id: buttongroups.rb,v 1.1.1.1 2002/12/22 14:19:46 taka-hr Exp $
**
** Copyright (C) 1992-2000 Trolltech AS.  All rights reserved.
**
** This file is part of an example program for Qt.  This example
** program may be used, distributed and modified without limitation.
**
*****************************************************************************/
=end
#include "buttongroups.h"
#include <qapplication.h>
require "qte"
include Qte
require "qpe"
include Qpe
require "buttongroups_lib.rb"

   a = QPEApplication.new( [$0]+ARGV );

    buttonsgroups = ButtonGroups.new;
    buttonsgroups.setCaption( "Examples for Buttons and Groups" );
    a.showMainWidget( buttonsgroups );

    a.exec();

